Running simulations — BuildingsPy documentation

# Running simulations

This module contains the class `buildingspy.simulate.Optimica` and `buildingspy.simulate.Dymola` that can be used to automate simulations using Optimica and Dymola, respectively.

Their API is identical where possible, but each class may have methods that are only applicable for one of the simulators. For example, the method `buildingspy.simulate.Optimica.Simulator.generateHtmlDiagnostics()` is only available for Optimica.